AGW Logo

svn SVN Revision 68742 For cubecolourdialog

This file contains the SVN revision history for cubecolourdialog, at revision 68742.

Available information include commit date, the name of the committer, the file size, the SVN log messages and a diff from the previous version (if available).


file_info File Information

  • Commit Date: 20-Oct-2008 20:05:15 UTC
  • Committer: AG
  • File Size: 139732 byte(s)

svn_log Log Messages

The following log message was entered by the committer:

  • FlatNotebook: fix issues with custom page and vertical/horizontal tiling of pages;
  • AuiBook: every time the AuiBook is split, copy over the custom buttons in the tab area of the newly created AuiBook;
  • Others: minor modifications to the docstrings.

svn_diff Diff To Previous Version (68362)

Version SVN diff:

--- wxPython/3rdParty/AGW/agw/cubecolourdialog.py   2011/07/24 21:36:47     68362
+++ wxPython/3rdParty/AGW/agw/cubecolourdialog.py   2011/08/16 16:37:37     68742
@@ -4,7 +4,7 @@
# Python Code By:
#
# Andrea Gavana, @ 16 Aug 2007
# Latest Revision: 14 Apr 2010, 12.00 GMT
#
#
# TODO List
@@ -88,7 +88,7 @@

CubeColourDialog is distributed under the wxPython license.

-Latest Revision: Andrea Gavana @ 14 Apr 2010, 12.00 GMT
+Latest Revision: Andrea Gavana @ 15 Aug 2011, 20.00 GMT

Version 0.3.

@@ -1175,6 +1175,7 @@

return 180.0*x/pi

+
def deg2rad(x):
"""
Transforms degrees into radians.
@@ -1184,6 +1185,7 @@

return x*pi/180.0

+
def toscale(x):
"""
Normalize a value as a function of the radius.
@@ -1193,6 +1195,7 @@

return x*RADIUS/255.0

+
def scaletomax(x):
"""
Normalize a value as a function of the radius.
@@ -1202,6 +1205,7 @@

return x*255.0/RADIUS

+
def rgb2html(colour):
"""
Transforms a RGB triplet into an html hex string.
@@ -4,7 +4,7 @@
#
# Andrea Gavana, @ 16 Aug 2007
-# Latest Revision: 14 Apr 2010, 12.00 GMT
+# Latest Revision: 15 Aug 2011, 20.00 GMT
#
#
Tree